@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 use utf8;
 use 5.008001;
 
-use version; our $VERSION = version->declare("v0.3.0");
+use version; our $VERSION = version->declare("v0.3.1");
 
 use Scalar::Util ();
 use File::Spec ();
@@ -156,9 +156,9 @@ sub check_word {
     return 1 if $word =~ /\A#[a-z0-9-]+\z/;
 
     # Suffix
-    return 1 if $word =~ /\A(.*)[^A-Za-z]\z/ && $self->check_word($1);
+    return 1 if $word =~ /\A(.*?)[^A-Za-z]+\z/ && $self->check_word($1);
     # Prefix
-    return 1 if $word =~ /\A[^A-Za-z](.*)\z/ && $self->check_word($1);
+    return 1 if $word =~ /\A[^A-Za-z]+(.*?)\z/ && $self->check_word($1);
 
     if ($word =~ /[^A-Za-z]+/) {
         my @words = split /[^A-Za-z]+/, $word;
